@@ -1,5 +1,5 @@
 from starlette_context.header_keys import HeaderKeys
-from starlette_context.plugins.plugin import Plugin
+from starlette_context.plugins.base import Plugin
 
 
 class UserAgentPlugin(Plugin):
